package api

import (
	"fmt"
	"sku3dweb/bus"
	"sku3dweb/db/model"
	"sort"
	"time"

	"github.com/gin-gonic/gin"
)

type ToMilvusReq struct {
	Scope    string  `json:"scope"`
	Url      string  `json:"url"`
	Limit    int     `json:"limit"`
	MaxScore float64 `json:"maxScore"`
	MinScore float64 `json:"minScore"`
}

func updateToMilvus(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	assetType := c.Param("assetType")
	id := c.Param("id")
	if len(assetType) < 1 || len(id) < 1 {
		return nil, fmt.Errorf("参数错误")
	}
	var req ToMilvusReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		return nil, err
	}

	isCompany := model.USERTYPE_COMPANY == apictx.User.UserType
	isSku3d := apictx.User.Parent == model.SKU3D_USERID

	srcColl := getAssetTypeCollectin(isCompany, isSku3d, req.Scope, assetType)
	tableName := fmt.Sprintf("%s_%s", srcColl, apictx.User.ID)
	// 删除旧的图片
	go deleteImageToMlivus(tableName, id)
	// 等待删除
	time.Sleep(50 * time.Millisecond)
	// 添加新的图片
	go uploadImageToMlivus(tableName, id, req.Url)
	return true, nil
}

func searchToMilvus(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	assetType := c.Param("assetType")
	var req ToMilvusReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		return nil, err
	}
	fmt.Printf("search params : %v\n", req)

	isCompany := model.USERTYPE_COMPANY == apictx.User.UserType
	isSku3d := apictx.User.Parent == model.SKU3D_USERID

	srcColl := getAssetTypeCollectin(isCompany, isSku3d, req.Scope, assetType)
	tableName := fmt.Sprintf("%s_%s", srcColl, apictx.User.ID)
	lists, err := searchImageToMlivus(tableName, &req)
	if err != nil {
		fmt.Println(err)
		return nil, err
	}
	fmt.Printf("image search result: %v\n", lists)
	handleLists := make([]map[string]interface{}, 0)
	if len(lists) > 0 {
		sort.Sort(SortMilvusSearchSlice(lists))
		lists := FilterMilvusSocreRange(lists, req.MaxScore, req.MinScore)

		return bus.BusTreeSearchImage(&bus.BusTreeSearchImageReq{
			DbName: Sku3dDbName,
			Coll:   srcColl,
			Result: lists,
		})
	}

	return handleLists, nil
}
