package model

import (
	"time"

	"go.mongodb.org/mongo-driver/bson/primitive"
)

type MatImage1 struct {
	Id        primitive.ObjectID `bson:"_id,omitempty" json:"_id"`
	UserId    primitive.ObjectID `bson:"userId,omitempty" json:"userId,omitempty"` //用户Id
	Thumbnail *OssType           `bson:"thumbnail,omitempty" json:"thumbnail"`     //封面图
	RawImage  *OssType           `bson:"rawImage,omitempty" json:"rawImage"`       //原始大图
	PhyWidth  int                `bson:"phyWidth,omitempty" json:"phyWidth"`       //物理尺寸 宽度
	PhyHeight int                `bson:"phyHeight,omitempty" json:"phyHeight"`     //物理尺寸 高度

	CreateTime time.Time `bson:"createTime,omitempty" json:"createTime"`
	UpdateTime time.Time `bson:"updateTime,omitempty" json:"updateTime"`

	NameCN string `bson:"nameCn,omitempty" json:"nameCn"` //中文名称
	NameEN string `bson:"nameEn,omitempty" json:"nameEn"` //英文名称
	From   string `bson:"from,omitempty" json:"from"`     //来源
	Price  int    `bson:"price,omitempty" json:"price"`   //价格 //单位分

	Categories []string `bson:"categories,omitempty" json:"categories"`   //所属分类Id
	CusNum     string   `bson:"cusNum,omitempty" json:"cusNum,omitempty"` //编号
}

type SerialNumer struct {
	Id     primitive.ObjectID `bson:"_id,omitempty" json:"_id"`
	CatId1 string             `bson:"catId1,omitempty" json:"catId1,omitempty"`
	CatId2 string             `bson:"catId2,omitempty" json:"catId2,omitempty"`
	CatId3 string             `bson:"catId3,omitempty" json:"catId3,omitempty"`
	Next   int                `bson:"next,omitempty" json:"next,omitempty"`
}

type MatImage struct {
	Id           primitive.ObjectID `bson:"_id,omitempty" json:"_id"`
	UserId       primitive.ObjectID `bson:"userId,omitempty" json:"userId,omitempty"`         // 用户Id
	Thumbnail    *OssType           `bson:"thumbnail,omitempty" json:"thumbnail"`             // 封面图
	RawImage     *OssType           `bson:"rawImage,omitempty" json:"rawImage"`               // 原始大图
	ProductImage *OssType           `bson:"productImage,omitempty" json:"productImage"`       // 商品图片
	CreateTime   time.Time          `bson:"createTime,omitempty" json:"createTime,omitempty"` // 创建日期
	// 商品信息
	CusNum         string    `bson:"cusNum,omitempty" json:"cusNum,omitempty"`                 // 公司商品编号（格式：分类编号+产品系列+3位流水号+产品用途）
	From           string    `bson:"from,omitempty" json:"from,omitempty"`                     // 来源（样品收集人）
	TypeCategory   string    `bson:"typeCategory,omitempty" json:"typeCategory,omitempty"`     // 种类分类
	TaxNameCN      string    `bson:"taxNameCn,omitempty" json:"taxNameCn,omitempty"`           // 报关商品中文名（必填）
	DevTime        time.Time `bson:"devTime,omitempty" json:"devTime,omitempty"`               // 开发日期
	Categories     []string  `bson:"categories,omitempty" json:"categories,omitempty"`         // 商品分类（如：革PVC、布坯类等）
	BaseCloth      string    `bson:"baseCloth,omitempty" json:"baseCloth,omitempty"`           // 基布
	SampleNumber   string    `bson:"sampleNumber,omitempty" json:"sampleNumber,omitempty"`     // 样品编号
	NameCN         string    `bson:"nameCn,omitempty" json:"nameCn,omitempty"`                 // 商品中文名
	ProductSeries  string    `bson:"productSeries,omitempty" json:"productSeries,omitempty"`   // 产品系列
	SurfaceProcess string    `bson:"surfaceProcess,omitempty" json:"surfaceProcess,omitempty"` // 表面工艺
	CatalogNumber  string    `bson:"catalogNumber,omitempty" json:"catalogNumber,omitempty"`   // 留样册号
	NameEN         string    `bson:"nameEn,omitempty" json:"nameEn,omitempty"`                 // 商品英文名
	ProductUsage   string    `bson:"productUsage,omitempty" json:"productUsage,omitempty"`     // 产品用途
	MnemonicSign   string    `bson:"mnemonicSign,omitempty" json:"mnemonicSign,omitempty"`     // 报关助记符
	UnitGroup      string    `bson:"unitGroup,omitempty" json:"unitGroup,omitempty"`           // 计量单位组
	OriginalNumber string    `bson:"originalNumber,omitempty" json:"originalNumber,omitempty"` // 原命名编号
	TaxGoodsNumber string    `bson:"taxGoodsNumber,omitempty" json:"taxGoodsNumber,omitempty"` // 报关商品编号

	// 商品厂家信息
	SupplierID     string `bson:"supplierId,omitempty" json:"supplierId,omitempty"`         // 供应商编号
	MainSupplier   string `bson:"mainSupplier,omitempty" json:"mainSupplier,omitempty"`     // 首选供应商
	Price          int    `bson:"price,omitempty" json:"price,omitempty"`                   // 价格（默认采购单价，单位：分）
	MainUnit       string `bson:"mainUnit,omitempty" json:"mainUnit,omitempty"`             // 主计量单位
	OperationCycle string `bson:"operationCycle,omitempty" json:"operationCycle,omitempty"` // 运营周期

	// 商品属性
	ExportProperty     *bool `bson:"exportProperty,omitempty" json:"exportProperty,omitempty"`         // 出口属性
	DomesticProperty   *bool `bson:"domesticProperty,omitempty" json:"domesticProperty,omitempty"`     // 内销属性
	InpurchaseProperty *bool `bson:"inpurchaseProperty,omitempty" json:"inpurchaseProperty,omitempty"` // 内购属性
	OutsourcedProperty *bool `bson:"outsourcedProperty,omitempty" json:"outsourcedProperty,omitempty"` // 委外属性

	// 体积重量
	Thickness          int     `bson:"thickness,omitempty" json:"thickness,omitempty"`                   // 厚度/高（单位：MM）
	PackageGrossWeight float64 `bson:"packageGrossWeight,omitempty" json:"packageGrossWeight,omitempty"` // 单位包材毛重（单位：KG）
	PhyWidth           int     `bson:"phyWidth,omitempty" json:"phyWidth,omitempty"`                     // 物理尺寸宽度（门幅/宽，单位：MM）
	ProductVolume      float64 `bson:"productVolume,omitempty" json:"productVolume,omitempty"`           // 商品单位体积
	PhyHeight          int     `bson:"phyHeight,omitempty" json:"phyHeight,omitempty"`                   // 物理尺寸高度（长度，单位：MM）
	SurfaceWeight      float64 `bson:"surfaceWeight,omitempty" json:"surfaceWeight,omitempty"`           // 面布克重
	ProductWeight      float64 `bson:"productWeight,omitempty" json:"productWeight,omitempty"`           // 产品克重（单位：KG）
	BackingWeight      float64 `bson:"backingWeight,omitempty" json:"backingWeight,omitempty"`           // 底布克重（单位：KG）
	PackageVolume      float64 `bson:"packageVolume,omitempty" json:"packageVolume,omitempty"`           // 单位包材体积（单位：CBM）
	Remarks            string  `bson:"remarks,omitempty" json:"remarks,omitempty"`                       // 备注
	FitMarket          string  `bson:"fitMarket,omitempty" json:"fitMarket,omitempty"`                   // 适合市场

	UpdateTime time.Time `bson:"updateTime,omitempty" json:"updateTime,omitempty"`
}
