package repo

import (
	"math/rand"
	"time"
)

func RedisGetUserById(ctx *RepoSession, id string) (result map[string]string, err error) {

	// 1、redis查,没有到mongodb中查询
	result, err = ctx.Redis.HGetAll(ctx.Ctx, "user_"+id).Result()

	if len(result) == 0 || err != nil {
		result = map[string]string{}

		// 2、mongodb查,赋值到redis
		//u := &model.User{}

		ok, res := RepoSeachDocMap(ctx, &DocSearchOptions{
			CollectName: CollectionUser,
			Query:       Map{"_id": id},
			Project:     []string{"avatar", "name"},
		})

		if !ok {
			result = map[string]string{"avatar": "https://sku3d-test.obs.cn-east-3.myhuaweicloud.com/u/test/images/uploads/1636709315965451800.png", "name": "未设置"}
		} else {
			for k, v := range res {
				switch v.(type) {
				case string:
					result[k] = v.(string)
				}
			}
		}

		ctx.Redis.HMSet(ctx.Ctx, "user_"+id, result)
		ctx.Redis.Expire(ctx.Ctx, "user_"+id, time.Duration(rand.New(rand.NewSource(time.Now().UnixNano())).Intn(10000000))*time.Millisecond)
	}

	return result, err
}
